==> haskell-wizards-1.0.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-3C14iHNvdkt3uJhP46rNMR
key: wizards-1.0.2-3C14iHNvdkt3uJhP46rNMR
license: BSD3
maintainer: liamoc@cse.unsw.edu.au
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
author: Liam O'\''Connor-Davis
exposed: True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.Internal
    System.Console.Wizard.Haskeline System.Console.Wizard.BasicIO
    System.Console.Wizard.Pure
abi: cf2d7231ce243404fdab55c7f26ad9c3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-3C14iHNvdkt3uJhP46rNMR
depends:
    base-4.9.1.0 containers-0.5.7.1
    control-monad-free-0.6.1-6sHLlBhFKrC1QUKEf8Gbv7 haskeline-0.7.3.0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wizards-1.0.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-ZspRevRBIDHbopg40X3g1
key: wizards-1.0.2-ZspRevRBIDHbopg40X3g1
license: BSD3
maintainer: liamoc@cse.unsw.edu.au
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
author: Liam O'\''Connor-Davis
exposed: True
indefinite: False
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure
abi: f0e4a4052ccd58875c7ea06f45ee7959
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-ZspRevRBIDHbopg40X3g1
depends:
    base-4.10.0.0 containers-0.5.10.2
    control-monad-free-0.6.1-DLPnWUouwirGGa6ZR8vSdg haskeline-0.7.4.0
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 transformers-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             control-monad-free-0.6.1-DLPnWUouwirGGa6ZR8vSdg=94eaf771a005b96b5a8660c952a4c1b0
             haskeline-0.7.4.0=ee72a1e6f6c246132a6260bcf7bd279e
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
